@@ -167,7 +167,7 @@ def get_layout(domain,
                     sg.Button("Erase saved htmls", key='-RESET-SAVED-HTMLS-', button_color='black')
                 ],
                 [
-                    sg.Button("Create new test", key='-CREATE-NEW-TEST-', button_color='red')
+                    sg.Button("Create new plan", key='-CREATE-NEW-TEST-', button_color='red')
                 ]
             ])
         ],
@@ -233,8 +233,7 @@ def get_layout(domain,
                                     sg.Column(
                                         [
                                             [
-                                                sg.Button('Copy html of element', button_color=('black', 'yellow'),
-                                                          key='-COPY-HTML-ELEMENT-'),
+                                                sg.Button('Copy html of element', key='-COPY-HTML-ELEMENT-'),
                                                 sg.Button('Copy html of whole site', button_color='green',
                                                           key='-COPY-HTML-'),
                                             ]
