@@ -39,7 +39,7 @@ class WebsiteTag:
 
     def _text_inside(self):
         if self.text is not None:
-            return f"text = {self.text.strip()}"
+            return f", text = '{self.text.strip()}'"
         return ""
 
     def attributes_to_html(self):
@@ -99,6 +99,8 @@ class WebsiteTag:
             return f'{self.bdd_attribute} {self.value_for_bdd}'
         elif self.value_for_bdd == 'assert element has certain text':
             return f'{self.bdd_attribute} element with xpath {self.xpath} should have text {self.attribute}'
+        elif self.value_for_bdd == 'assert element contains text':
+            return f'{self.bdd_attribute} element with xpath {self.xpath} contains text {self.attribute}'
         elif self.value_for_bdd == 'attaching file to file input':
             return f'{self.bdd_attribute} attaching file input with xpath {self.xpath} with file {self.attribute}'
 
