@@ -2,8 +2,6 @@ import lxml.html as PARSER
 
 
 def get_number_of_match(html, xpath):
-    print(html)
-    print(xpath)
     if html is not None or html != '':
         root = PARSER.fromstring(html)
 
